@@ -53,7 +53,13 @@ static GtkWidget *sel_label;
 static GtkWidget *vis_label;
 static GtkWidget *popup;
 static GtkWidget *omenu;
+static GtkWidget *omenu2;
+static GtkWidget *omenu3;
 static char fullpath[1024];
+static GtkTooltips *tooltips;
+
+GdkColor col_fg;
+GdkColor col_bg;
 
 
 #define FTW_F   1
@@ -113,6 +119,8 @@ dopath (GtkCTree *ctree, GList *parent)
   
   if ((dp = opendir (fullpath)) == NULL)
     {
+      gtk_ctree_set_foreground(ctree, parent, &col_fg);
+      gtk_ctree_set_background(ctree, parent, &col_bg);
       gtk_ctree_set_text (ctree, parent, 2, "not readable");
       return;
     }
@@ -136,8 +144,7 @@ dopath (GtkCTree *ctree, GList *parent)
   
 }
 
-#ifndef __GLIBC__ 
-char * basename (char *s) 
+char * my_basename (char *s) 
 {
   char *r;
   gint len;
@@ -153,8 +160,6 @@ char * basename (char *s)
   r = strrchr(s, '/');
   return r ? r + 1 : s;
 }
-#endif
-
 
 GList * insert_item (char *pathname, const struct stat *statptr, int type,
 		     GtkCTree *ctree, GList *parent)
@@ -191,12 +196,12 @@ GList * insert_item (char *pathname, const struct stat *statptr, int type,
       switch (statptr->st_mode & S_IFMT)
 	{
 	case S_IFLNK:
-	  num = sprintf (bufname, "%s -> ",basename(pathname));
+	  num = sprintf (bufname, "%s -> ",my_basename(pathname));
 	  num += readlink (pathname, &bufname[num], sizeof(bufname)-num);
 	  bufname[num] = 0;
 	  text[1] = bufname;
 	  child = gtk_ctree_insert  (ctree, parent,  NULL, text, 5, pixmap4,
-				     mask4, NULL, NULL, FALSE);
+				     mask4, NULL, NULL, TRUE, FALSE);
 	  GTK_CTREE_ROW (child)->row.data = 0;
 	  files++;
 	  break;
@@ -205,10 +210,11 @@ GList * insert_item (char *pathname, const struct stat *statptr, int type,
 	case S_IFIFO:
 	case S_IFSOCK:
 	case S_IFREG:
-	  sprintf (bufname, "%s", basename(pathname));
+	  sprintf (bufname, "%s", my_basename(pathname));
 	  text[1] = bufname;
 	  child = gtk_ctree_insert (ctree, parent,  NULL, text,5,
-				    pixmap3, mask3, NULL, NULL, FALSE);
+				    pixmap3, mask3, NULL, NULL, TRUE, FALSE);
+	  
 	  GTK_CTREE_ROW (child)->row.data = 0;
 	  files++;
 	  break;
@@ -220,10 +226,11 @@ GList * insert_item (char *pathname, const struct stat *statptr, int type,
     case FTW_D:
       if (parent)
 	level = GTK_CTREE_ROW (parent)->level;
-      sprintf (bufname, "%s", basename(pathname));
+      sprintf (bufname, "%s", my_basename(pathname));
       text[1] = bufname;
       child = gtk_ctree_insert  (ctree, parent,  NULL, text, 5,
-				 pixmap1, mask1, pixmap2, mask2, (level == 0));
+				 pixmap1, mask1, pixmap2, mask2, FALSE, 
+				 (level == 0));
       GTK_CTREE_ROW (child)->row.data = (gpointer) 1;
       dirs++;
       break;
@@ -269,17 +276,33 @@ void after_press (GtkCTree *ctree, gpointer data)
   gtk_label_set (GTK_LABEL (file_label), buf);
 }
 
+void before_move (GtkCTree *ctree, GList *child, GList *parent, 
+		  GList *sibling, gpointer data)
+{
+  g_print ("Moving \"%s\" to \"%s\" with sibling \"%s\".\n", 
+	   GTK_CELL_PIXTEXT (((GtkCListRow*) 
+			      (GTK_CTREE_ROW (child)))->cell[1])->text,
+    (parent) ?
+    GTK_CELL_PIXTEXT (((GtkCListRow*) 
+		       (GTK_CTREE_ROW (parent)))->cell[1])->text : "nil",
+    (sibling) ?
+    GTK_CELL_PIXTEXT (((GtkCListRow*) 
+		       (GTK_CTREE_ROW (sibling)))->cell[1])->text : "nil");
+}
+
 gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 {
   gint row;
   gint column;
   gint num;
   GList *work;
+  gint res;
   
-  if (!gtk_clist_get_selection_info (GTK_CLIST (ctree), event->x, event->y, 
-				     &row, &column))
+  res = gtk_clist_get_selection_info (GTK_CLIST (ctree), event->x, event->y, 
+				      &row, &column);
+  if (!res && event->button != 3)
     return FALSE;
-    
+
   work = g_list_nth (GTK_CLIST (ctree)->row_list, row);
 
   switch (event->button)
@@ -288,11 +311,12 @@ gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data)
       if (GTK_CLIST (ctree)->selection_mode == GTK_SELECTION_MULTIPLE &&
 	  event->state & GDK_SHIFT_MASK)
 	{
-	  
+	  gtk_clist_freeze (GTK_CLIST (ctree));
 	  if (GTK_CTREE_ROW (work)->row.state == GTK_STATE_SELECTED) 
 	    gtk_ctree_unselect_recursive (ctree, work);
 	  else
 	    gtk_ctree_select_recursive (ctree, work);
+	  gtk_clist_thaw (GTK_CLIST (ctree));
 	  after_press (ctree, NULL);
 	  gtk_signal_emit_stop_by_name (GTK_OBJECT (ctree), 
 					"button_press_event");
@@ -300,17 +324,17 @@ gint button_press (GtkCTree *ctree, GdkEventButton *event, gpointer data)
 	}
       break;
     case  2:
-	
       num = my_list_find (GTK_CLIST (ctree)->row_list, GTK_CTREE_ROW (work));
-      
       if (GTK_CTREE_ROW (work)->children && 
 	  gtk_ctree_is_hot_spot (ctree, GTK_CTREE_ROW (work), num, event->x,
 				 event->y))
 	{
+	  gtk_clist_freeze (GTK_CLIST (ctree));
 	  if (GTK_CTREE_ROW (work)->expanded)
 	    gtk_ctree_collapse_recursive (ctree, work);
 	  else
 	    gtk_ctree_expand_recursive (ctree, work);
+	  gtk_clist_thaw (GTK_CLIST (ctree));
 	  after_press (ctree, NULL);
 	  gtk_signal_emit_stop_by_name (GTK_OBJECT (ctree), 
 					"button_press_event");
@@ -337,32 +361,60 @@ void count_items (GtkCTree *ctree, GList *list)
 
 void expand_all (GtkWidget *widget, GtkCTree *ctree)
 {
+  GList *work;
+
   gtk_clist_freeze (GTK_CLIST (ctree));
-  gtk_ctree_expand_recursive (ctree, GTK_CLIST (ctree)->row_list);
+  work = GTK_CLIST (ctree)->row_list;
+  while (work)
+    {
+      gtk_ctree_expand_recursive (ctree, work);
+      work = GTK_CTREE_ROW (work)->sibling;
+    }
   gtk_clist_thaw (GTK_CLIST (ctree));
   after_press (ctree, NULL);
 }
 
 void collapse_all (GtkWidget *widget, GtkCTree *ctree)
 {
+  GList *work;
+
   gtk_clist_freeze (GTK_CLIST (ctree));
-  gtk_ctree_collapse_recursive (ctree, GTK_CLIST (ctree)->row_list);
+  work = GTK_CLIST (ctree)->row_list;
+  while (work)
+    {
+      gtk_ctree_collapse_recursive (ctree, work);
+      work = GTK_CTREE_ROW (work)->sibling;
+    }
   gtk_clist_thaw (GTK_CLIST (ctree));
   after_press (ctree, NULL);
 }
 
 void select_all (GtkWidget *widget, GtkCTree *ctree)
 {
+  GList *work;
+
   gtk_clist_freeze (GTK_CLIST (ctree));
-  gtk_ctree_select_recursive (ctree, GTK_CLIST (ctree)->row_list);
+  work = GTK_CLIST (ctree)->row_list;
+  while (work)
+    {
+      gtk_ctree_select_recursive (ctree, work);
+      work = GTK_CTREE_ROW (work)->sibling;
+    }
   gtk_clist_thaw (GTK_CLIST (ctree));
   after_press (ctree, NULL);
 }
 
 void unselect_all (GtkWidget *widget, GtkCTree *ctree)
 {
+  GList *work;
+
   gtk_clist_freeze (GTK_CLIST (ctree));
-  gtk_ctree_unselect_recursive (ctree, GTK_CLIST (ctree)->row_list);
+  work = GTK_CLIST (ctree)->row_list;
+  while (work)
+    {
+      gtk_ctree_unselect_recursive (ctree, work);
+      work = GTK_CTREE_ROW (work)->sibling;
+    }
   gtk_clist_thaw (GTK_CLIST (ctree));
   after_press (ctree, NULL);
 }
@@ -371,19 +423,49 @@ void remove_selection (GtkWidget *widget, GtkCTree *ctree)
 {
   GList *work;
   GList *selection;
+  GList *tmp;
+  GList *new_sel;
+
+  selection = GTK_CLIST (ctree)->selection;
+  new_sel = NULL;
 
   gtk_clist_freeze (GTK_CLIST (ctree));
-  selection = GTK_CLIST (ctree)->selection;
+
   while (selection)
     {
       work = selection->data;
       if (GTK_CTREE_ROW (work)->row.data)
-	gtk_ctree_recursive (ctree, work, (GtkCTreeFunc) count_items, NULL);
+	gtk_ctree_post_recursive (ctree, work, 
+				  (GtkCTreeFunc) count_items, NULL);
       else
 	files--;
+
+      if (GTK_CLIST (ctree)->selection_mode == GTK_SELECTION_BROWSE)
+	{
+	  tmp = gtk_ctree_find_row (ctree, GTK_CLIST (ctree)->row_list, 
+				    GTK_CTREE_ROW (work));
+	  if (GTK_CTREE_ROW (tmp)->children)
+	    {
+	      new_sel = GTK_CTREE_ROW (tmp)->sibling;
+	      if (!new_sel)
+		new_sel = tmp->prev;
+	    }
+	  else
+	    {
+	      if (tmp->next)
+		new_sel = tmp->next;
+	      else
+		new_sel = tmp->prev;
+	    }
+	}
+
       gtk_ctree_remove (ctree, work);
       selection = GTK_CLIST (ctree)->selection;
     }
+
+  if (new_sel)
+    gtk_ctree_select (ctree, new_sel);
+
   gtk_clist_thaw (GTK_CLIST (ctree));
   after_press (ctree, NULL);
 }
@@ -404,48 +486,70 @@ void window_close (GtkWidget *widget, GtkWidget *window)
   gtk_main_quit ();
 }
 
-void toggle_lines (GtkWidget *widget, GtkCTree *ctree)
+void change_indent (GtkWidget *widget, GtkCTree *ctree)
 {
-  gtk_ctree_set_draw_lines (ctree, GTK_TOGGLE_BUTTON (widget)->active);
+  gtk_ctree_set_indent (ctree, GTK_ADJUSTMENT(widget)->value);
 }
 
-void toggle_sel_mode (GtkWidget *widget, GtkCTree *ctree)
+void toggle_reorderable (GtkWidget *widget, GtkCTree *ctree)
+{
+  gtk_ctree_set_reorderable (ctree, GTK_TOGGLE_BUTTON (widget)->active);
+}
+
+void toggle_line_style (GtkWidget *widget, GtkCTree *ctree)
 {
-  GtkCList *clist;
-  GList *selection;
-  GList *work;
   gint i;
 
   if (!GTK_WIDGET_MAPPED (widget))
     return;
 
   RADIOMENUTOGGLED ((GtkRadioMenuItem *)
-		    (((GtkOptionMenu *)omenu)->menu_item),i);
+		    (((GtkOptionMenu *)omenu2)->menu_item),i);
 
-  clist = GTK_CLIST (ctree);
+  gtk_ctree_set_line_style (ctree, (GtkCTreeLineStyle) (2-i));
+}
 
-  if ((selection = clist->selection))
-    {
-      gtk_clist_freeze (clist);
-      while (selection)
-	{
-	  work = selection->data;
-	  selection = selection->next;
-	  gtk_ctree_unselect (ctree, work);
-	}
-      gtk_clist_thaw (clist);
-      after_press (ctree, NULL);
-    }
-  gtk_clist_set_selection_mode (clist, (GtkSelectionMode) (3-i));
+void toggle_justify (GtkWidget *widget, GtkCTree *ctree)
+{
+  gint i;
+
+  if (!GTK_WIDGET_MAPPED (widget))
+    return;
+
+  RADIOMENUTOGGLED ((GtkRadioMenuItem *)
+		    (((GtkOptionMenu *)omenu3)->menu_item),i);
+
+  gtk_clist_set_column_justification (GTK_CLIST (ctree), 1, 
+				      (GtkJustification) (1-i));
+}
+
+void toggle_sel_mode (GtkWidget *widget, GtkCTree *ctree)
+{
+  gint i;
+
+  if (!GTK_WIDGET_MAPPED (widget))
+    return;
+
+  RADIOMENUTOGGLED ((GtkRadioMenuItem *)
+		    (((GtkOptionMenu *)omenu)->menu_item), i);
+
+  gtk_ctree_set_selection_mode (ctree, (GtkSelectionMode) (3-i));
+  after_press (ctree, NULL);
 }
 
 void rebuild_tree (GtkWidget *widget, GtkCTree *ctree)
 {
+  GList *work;
+
   if (!strlen(GTK_ENTRY (widget)->text))
     return;
   gtk_clist_freeze (GTK_CLIST (ctree));
-  if (GTK_CLIST (ctree)->row_list)
-    gtk_ctree_remove (ctree, GTK_CLIST (ctree)->row_list);
+  work = GTK_CLIST (ctree)->row_list;
+  while (work)
+    {
+      gtk_ctree_remove (ctree, work);
+      work = GTK_CTREE_ROW (work)->sibling;
+    }
   dirs = files = 0;
   strcpy (fullpath, GTK_ENTRY (widget)->text);
   dopath (ctree, NULL);
@@ -468,13 +572,18 @@ void create_ctree ()
   GtkWidget *menu;
   GtkWidget *submenu;
   GtkWidget *check;
+  GtkAdjustment *adj;
+  GtkWidget *spinner;
   GSList *group;
   GdkColor transparent;
+
   char *title[] = { "Owner" , "Files" , "Size" };
   char buf[80];
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
+  tooltips = gtk_tooltips_new ();
+
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
 
@@ -489,29 +598,129 @@ void create_ctree ()
   gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 5);
   gtk_entry_set_text (GTK_ENTRY (entry), fullpath);
   
-  check = gtk_check_button_new_with_label ("Draw lines");
-  gtk_box_pack_start (GTK_BOX (hbox), check, FALSE, TRUE, 0);
-  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (check), TRUE);
+  button = gtk_button_new_with_label ("Close");
+  gtk_signal_connect (GTK_OBJECT (button), "clicked",
+                      GTK_SIGNAL_FUNC (window_close), window);
+  gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, TRUE, 0);
 
   ctree = GTK_CTREE (gtk_ctree_new_with_titles (3, 1, title));
+  gtk_ctree_set_reorderable (ctree, TRUE);
   gtk_signal_connect (GTK_OBJECT (ctree), "button_press_event",
 		      GTK_SIGNAL_FUNC (button_press), NULL);
   gtk_signal_connect_after (GTK_OBJECT (ctree), "button_press_event",
 			    GTK_SIGNAL_FUNC (after_press), NULL);
+  gtk_signal_connect (GTK_OBJECT (ctree), "tree_move",
+		      GTK_SIGNAL_FUNC (before_move), NULL);
   gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET(ctree), TRUE, TRUE, 0);
   gtk_clist_column_titles_passive (GTK_CLIST (ctree));
   gtk_clist_set_column_justification (GTK_CLIST (ctree), 2, GTK_JUSTIFY_RIGHT);
-  gtk_clist_set_selection_mode (GTK_CLIST (ctree), GTK_SELECTION_MULTIPLE);
+  gtk_clist_set_selection_mode (GTK_CLIST (ctree), GTK_SELECTION_EXTENDED);
   gtk_clist_set_policy (GTK_CLIST (ctree), 
 			GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC);
   gtk_clist_set_column_width (GTK_CLIST (ctree), 0, 70);
   gtk_clist_set_column_width (GTK_CLIST (ctree), 1, 290);
   gtk_clist_set_column_width (GTK_CLIST (ctree), 2, 80);
 
+  /*gtk_clist_set_row_height (GTK_CLIST (ctree), 30);*/
+
+  col_fg.red   = 65535;
+  col_fg.green = 65535;
+  col_fg.blue  = 0;
+  gdk_color_alloc (gtk_widget_get_colormap (GTK_WIDGET(ctree)), &col_fg);
+  col_bg.red   = 65535;
+  col_bg.green = 0;
+  col_bg.blue  = 0;
+  gdk_color_alloc (gtk_widget_get_colormap (GTK_WIDGET(ctree)), &col_bg);
+
+  hbox = gtk_hbox_new (TRUE, 5);
+  gtk_container_border_width (GTK_CONTAINER (hbox), 5);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
+
+  hbox2 = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), hbox2, FALSE, TRUE, 0);
+
+  label = gtk_label_new ("Indent :");
+  gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, TRUE, 0);
+
+  adj = (GtkAdjustment *) gtk_adjustment_new (20, 0, 60, 1, 10, 0);
+  spinner = gtk_spin_button_new (adj, 0, 0);
+  gtk_tooltips_set_tip (tooltips, spinner, "Tree indentation.", NULL);
+  gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
+		      GTK_SIGNAL_FUNC (change_indent), ctree);
+  gtk_box_pack_start (GTK_BOX (hbox2), spinner, FALSE, TRUE, 5);
+
+  check = gtk_check_button_new_with_label ("Reorderable");
+  gtk_tooltips_set_tip (tooltips, check,
+			"Tree items can be reordered by dragging.", NULL);
   gtk_signal_connect (GTK_OBJECT (check), "clicked",
-		      GTK_SIGNAL_FUNC (toggle_lines), ctree);
+		      GTK_SIGNAL_FUNC (toggle_reorderable), ctree);
+  gtk_box_pack_start (GTK_BOX (hbox), check, FALSE, TRUE, 0);
+  gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (check), TRUE);
+
+  omenu2 = gtk_option_menu_new ();
+  gtk_tooltips_set_tip (tooltips, omenu2, "The tree's line style.", NULL);
+
+  menu = gtk_menu_new ();
+  submenu = NULL;
+  group = NULL;
+      
+  menu_item = gtk_radio_menu_item_new_with_label (group, "Solid");
+  gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
+                      GTK_SIGNAL_FUNC (toggle_line_style), ctree);
+  group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
+  gtk_menu_append (GTK_MENU (menu), menu_item);
+  gtk_check_menu_item_set_state (GTK_CHECK_MENU_ITEM (menu_item), TRUE);
+  gtk_widget_show (menu_item);
+
+  menu_item = gtk_radio_menu_item_new_with_label (group, "Dotted");
+  gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
+                      GTK_SIGNAL_FUNC (toggle_line_style), ctree);
+  group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
+  gtk_menu_append (GTK_MENU (menu), menu_item);
+  gtk_widget_show (menu_item);
+
+  menu_item = gtk_radio_menu_item_new_with_label (group, "No lines");
+  gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
+                      GTK_SIGNAL_FUNC (toggle_line_style), ctree);
+  group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
+  gtk_menu_append (GTK_MENU (menu), menu_item);
+  gtk_widget_show (menu_item);
+
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu2), menu);
+  gtk_box_pack_start (GTK_BOX (hbox), omenu2, FALSE, TRUE, 0);
+
+  gtk_option_menu_set_history (GTK_OPTION_MENU (omenu2), 0);
+
+  omenu3 = gtk_option_menu_new ();
+  gtk_tooltips_set_tip (tooltips, omenu3, "The tree's justification.", NULL);
+
+  menu = gtk_menu_new ();
+  submenu = NULL;
+  group = NULL;
+      
+  menu_item = gtk_radio_menu_item_new_with_label (group, "Left");
+  gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
+                      GTK_SIGNAL_FUNC (toggle_justify), ctree);
+  group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
+  gtk_menu_append (GTK_MENU (menu), menu_item);
+  gtk_check_menu_item_set_state (GTK_CHECK_MENU_ITEM (menu_item), TRUE);
+  gtk_widget_show (menu_item);
+
+  menu_item = gtk_radio_menu_item_new_with_label (group, "Right");
+  gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
+                      GTK_SIGNAL_FUNC (toggle_justify), ctree);
+  group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
+  gtk_menu_append (GTK_MENU (menu), menu_item);
+  gtk_widget_show (menu_item);
+
+  gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu3), menu);
+  gtk_box_pack_start (GTK_BOX (hbox), omenu3, FALSE, TRUE, 0);
+
+  gtk_option_menu_set_history (GTK_OPTION_MENU (omenu3), 0);
 
   omenu = gtk_option_menu_new ();
+  gtk_tooltips_set_tip (tooltips, omenu, "The list's selection mode.", NULL);
+
   menu = gtk_menu_new ();
   submenu = NULL;
   group = NULL;
@@ -535,7 +744,6 @@ void create_ctree ()
                       GTK_SIGNAL_FUNC (toggle_sel_mode), ctree);
   group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
   gtk_menu_append (GTK_MENU (menu), menu_item);
-  gtk_check_menu_item_set_state (GTK_CHECK_MENU_ITEM (menu_item), TRUE);
   gtk_widget_show (menu_item);
 
   menu_item = gtk_radio_menu_item_new_with_label (group, "Extended");
@@ -543,17 +751,13 @@ void create_ctree ()
                       GTK_SIGNAL_FUNC (toggle_sel_mode), ctree);
   group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (menu_item));
   gtk_menu_append (GTK_MENU (menu), menu_item);
+  gtk_check_menu_item_set_state (GTK_CHECK_MENU_ITEM (menu_item), TRUE);
   gtk_widget_show (menu_item);
   
   gtk_option_menu_set_menu (GTK_OPTION_MENU (omenu), menu);
-  gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), omenu, FALSE, TRUE, 0);
 
-  button = gtk_button_new_with_label ("Close");
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      GTK_SIGNAL_FUNC (window_close), window);
-  gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, TRUE, 0);
-
-  gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), 2);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (omenu), 3);
 
   popup = gtk_menu_new ();
   gtk_menu_attach_to_widget (GTK_MENU (popup), GTK_WIDGET (window), detacher);
@@ -617,7 +821,6 @@ void create_ctree ()
   gtk_container_add (GTK_CONTAINER (frame), hbox);
 
   frame = gtk_frame_new (NULL);
-  gtk_container_border_width (GTK_CONTAINER (frame), 1);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
   gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, TRUE, 0);
 
@@ -633,7 +836,6 @@ void create_ctree ()
   gtk_box_pack_end (GTK_BOX (hbox2), dir_label, FALSE, TRUE, 5);
 
   frame = gtk_frame_new (NULL);
-  gtk_container_border_width (GTK_CONTAINER (frame), 1);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
   gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, TRUE, 0);
 
@@ -649,7 +851,6 @@ void create_ctree ()
   gtk_box_pack_end (GTK_BOX (hbox2), file_label, FALSE, TRUE, 5);
 
   frame = gtk_frame_new (NULL);
-  gtk_container_border_width (GTK_CONTAINER (frame), 1);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
   gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, TRUE, 0);
 
@@ -665,7 +866,6 @@ void create_ctree ()
   gtk_box_pack_end (GTK_BOX (hbox2), sel_label, FALSE, TRUE, 5);
 
   frame = gtk_frame_new (NULL);
-  gtk_container_border_width (GTK_CONTAINER (frame), 1);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
   gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, TRUE, 0);
 
@@ -695,7 +895,7 @@ int main (int argc, char *argv[])
   gtk_init (&argc, &argv);
   if (argc > 2 || (argc == 2 && !strcmp(argv[1], "--help")))
     {
-      g_print ("usage : %s [directory]\n", basename(argv[0]));
+      g_print ("usage : %s [directory]\n", my_basename(argv[0]));
       exit (1);
     }
   if (argc == 2)
